==> dataminer-pool-manager-1.0.0-20170515.160744-33-sources.jar: org/gcube/dataanalysis/dataminer/poolmanager/service/DMPMJob.java <==
package org.gcube.dataanalysis.dataminer.poolmanager.service;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.PrintStream;
import java.util.LinkedList;
import java.util.List;
import java.util.UUID;

import org.gcube.dataanalysis.dataminer.poolmanager.ansible.AnsibleWorker;
import org.gcube.dataanalysis.dataminer.poolmanager.ansiblebridge.AnsibleBridge;
import org.gcube.dataanalysis.dataminer.poolmanager.datamodel.Algorithm;
import org.gcube.dataanalysis.dataminer.poolmanager.datamodel.Cluster;
import org.gcube.dataanalysis.dataminer.poolmanager.datamodel.Dependency;
import org.gcube.dataanalysis.dataminer.poolmanager.util.SVNUpdater;
import org.tmatesoft.svn.core.SVNException;

public abstract class DMPMJob {
	
	
	protected SVNUpdater svnUpdater;
	protected File jobLogs;
	
	protected String id;
	
	public DMPMJob(SVNUpdater svnUpdater){
		this.svnUpdater = svnUpdater;
		this.id = UUID.randomUUID().toString();
		
		//TODO: dmpm work directory should be loaded from configuration file
		this.jobLogs = new File(System.getProperty("user.home")+File.separator+"dataminer-pool-manager"+File.separator+"jobs");
	
		this.jobLogs.mkdirs();
	}

	
	public String start(){
		new Thread(new Runnable() {
			@Override
			public void run() {
				try {
					execute();
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		}).start();
		
		return this.id;
	}
	
	protected AnsibleWorker createWorker(Algorithm algo,
			Cluster dataminerCluster,
			boolean includeAlgorithmDependencies,
			String user){
		AnsibleBridge ansibleBridge = new AnsibleBridge();
		try {
			return ansibleBridge.createWorker(algo, dataminerCluster, includeAlgorithmDependencies, user);
		} catch (IOException e) {
			e.printStackTrace();
		}
		return null;
		
	}
	
	protected abstract void execute();
	
	protected int executeAnsibleWorker(AnsibleWorker worker) throws IOException, InterruptedException, SVNException{
		File path = new File(worker.getWorkdir() + File.separator + "jobs");
		path.mkdirs();
		File n = new File(this.jobLogs + File.separator + this.id);
		FileOutputStream fos = new FileOutputStream(n, true);
		PrintStream ps = new PrintStream(fos);
		return worker.execute(ps);
	}
	
	
	protected void updateSVNDependencies(Algorithm algo, boolean stagingVRE) throws IOException, SVNException {
		for (Dependency d : algo.getDependencies()) {

			if (d.getType().equals("os")) {
				List<String> ls = new LinkedList<String>();
				ls.add(d.getName());
				this.svnUpdater.updateSVN((stagingVRE ? "test_": "") + "r_deb_pkgs.txt", ls);
			}
			if (d.getType().equals("cran")) {
				List<String> ls = new LinkedList<String>();
				ls.add(d.getName());
				this.svnUpdater.updateSVN((stagingVRE ? "test_": "") + "r_cran_pkgs.txt", ls);
			}
			if (d.getType().equals("github")) {
				List<String> ls = new LinkedList<String>();
				ls.add(d.getName());
				this.svnUpdater.updateSVN((stagingVRE ? "test_": "") + "r_github_pkgs.txt", ls);
			}
		}
	}

}

==> dataminer-pool-manager-2.0.0-20170919.125549-69-sources.jar: org/gcube/dataanalysis/dataminer/poolmanager/service/DMPMJob.java <==
package org.gcube.dataanalysis.dataminer.poolmanager.service;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.PrintStream;
import java.io.PrintWriter;
import java.util.LinkedList;
import java.util.List;
import java.util.UUID;

import org.gcube.dataanalysis.dataminer.poolmanager.ansible.AnsibleWorker;
import org.gcube.dataanalysis.dataminer.poolmanager.ansiblebridge.AnsibleBridge;
import org.gcube.dataanalysis.dataminer.poolmanager.datamodel.Algorithm;
import org.gcube.dataanalysis.dataminer.poolmanager.datamodel.Cluster;
import org.gcube.dataanalysis.dataminer.poolmanager.datamodel.Dependency;
import org.gcube.dataanalysis.dataminer.poolmanager.util.SVNUpdater;
import org.tmatesoft.svn.core.SVNException;


public abstract class DMPMJob {
	
	
	protected SVNUpdater svnUpdater;
	protected File jobLogs;
	
	protected String id;
	
	public DMPMJob(SVNUpdater svnUpdater){
		this.svnUpdater = svnUpdater;
		this.id = UUID.randomUUID().toString();
		
		//TODO: dmpm work directory should be loaded from configuration file
		this.jobLogs = new File(System.getProperty("user.home")+File.separator+"dataminer-pool-manager"+File.separator+"jobs");
	
		this.jobLogs.mkdirs();
	}

	
	public String start(){
		new Thread(new Runnable() {
			@Override
			public void run() {
				try {
					execute();
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		}).start();
		
		return this.id;
	}
	
	protected AnsibleWorker createWorker(Algorithm algo,
			Cluster dataminerCluster,
			boolean includeAlgorithmDependencies,
			String user){
		AnsibleBridge ansibleBridge = new AnsibleBridge();
		try {
			return ansibleBridge.createWorker(algo, dataminerCluster, includeAlgorithmDependencies, user);
		} catch (IOException e) {
			e.printStackTrace();
		}
		return null;
		
	}
	
	protected abstract void execute();
	
	protected int executeAnsibleWorker(AnsibleWorker worker) throws IOException, InterruptedException, SVNException{
		File path = new File(worker.getWorkdir() + File.separator + "jobs");
		path.mkdirs();
		
		File n = new File(this.jobLogs + File.separator + this.id);
		FileOutputStream fos = new FileOutputStream(n, true);
		PrintStream ps = new PrintStream(fos);	
		
//		File m = new File(this.jobLogs + File.separator + this.id + "_exitStatus");
//		PrintWriter fos2 = new PrintWriter(m, "UTF-8");
				
		return worker.execute(ps);
	}

}
